@@ -1,8 +1,5 @@
 /*
- * Copyright (C) 2020-2024 Savoir-faire Linux Inc.
- * Author : Edric Ladent Milaret<edric.ladent - milaret @savoirfairelinux.com>
- * Author : Andreas Traczyk<andreas.traczyk @savoirfairelinux.com>
- * Author: Mingrui Zhang <mingrui.zhang@savoirfairelinux.com>
+ * Copyright (C) 2020-2025 Savoir-faire Linux Inc.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -165,7 +162,7 @@ AvAdapter::shareWayland(bool entireScreen)
 
     int err = portal->getPipewireFd();
     if (err == EACCES) {
-        qInfo() << "Can't share screen: permission denied";
+        qInfo() << "Unable to share screen: permission denied";
         return;
     } else if (err != 0) {
         qWarning() << "Failed to get PipeWire fd. Error code:" << err;
@@ -178,7 +175,7 @@ AvAdapter::shareWayland(bool entireScreen)
                            .arg(portal->pipewireFd)
                            .arg(portal->pipewireNode);
 #ifndef ENABLE_LIBWRAP
-    // If the daemon is running as a separate process, then it can't directly use the
+    // If the daemon is running as a separate process, then it is unable to directly use the
     // PipeWire file descriptor opened by the client, so it will attempt to duplicate
     // it using the pidfd_getfd system call. This requires the daemon process to have
     // ptrace permission on the client process. On some systems, this will be true by
@@ -348,9 +345,11 @@ AvAdapter::shareScreenArea(unsigned x, unsigned y, unsigned width, unsigned heig
 }
 
 void
-AvAdapter::shareWindow(const QString& windowProcessId, const QString& windowId)
+AvAdapter::shareWindow(const QString& windowProcessId, const QString& windowId, const int fps)
 {
-    auto resource = lrcInstance_->getCurrentCallModel()->getDisplay(windowProcessId, windowId);
+    auto resource = lrcInstance_->getCurrentCallModel()->getDisplay(windowProcessId,
+                                                                    windowId,
+                                                                    fps);
     auto callId = lrcInstance_->getCurrentCallId();
 
     muteCamera_ = !isCapturing();
@@ -359,7 +358,10 @@ AvAdapter::shareWindow(const QString& windowProcessId, const QString& windowId)
 }
 
 QString
-AvAdapter::getSharingResource(int screenId, const QString& windowProcessId, const QString& windowId)
+AvAdapter::getSharingResource(int screenId,
+                              const QString& windowProcessId,
+                              const QString& windowId,
+                              const int fps)
 {
     if (screenId == -1) {
         const auto arrangementRect = getAllScreensBoundingRect();
@@ -390,7 +392,7 @@ AvAdapter::getSharingResource(int screenId, const QString& windowProcessId, cons
                                                                rect.height()
                                                                    * screen->devicePixelRatio());
     } else if (!windowId.isEmpty()) {
-        return lrcInstance_->getCurrentCallModel()->getDisplay(windowProcessId, windowId);
+        return lrcInstance_->getCurrentCallModel()->getDisplay(windowProcessId, windowId, fps);
     }
 
     return "";
