@@ -1,7 +1,5 @@
 /*
- * Copyright (C) 2020-2024 Savoir-faire Linux Inc.
- * Author: Mingrui Zhang <mingrui.zhang@savoirfairelinux.com>
- * Author: Andreas Traczyk <andreas.traczyk@savoirfairelinux.com>
+ * Copyright (C) 2020-2025 Savoir-faire Linux Inc.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -173,10 +171,20 @@ ConversationsAdapter::onNewUnreadInteraction(const QString& accountId,
         if (interaction.authorUri == accountInfo.profileInfo.uri)
             return;
         auto from = accountInfo.contactModel->bestNameForContact(interaction.authorUri);
-        auto body_ = interaction.body;
+        QString displayedString;
 
-        if (interaction.type == interaction::Type::DATA_TRANSFER) {
-            body_ = interaction.commit.value("displayName");
+        // Add special handling for member events
+        if (interaction.type == interaction::Type::CONTACT) {
+            auto action = interaction.commit.value("action");
+            if (action == "join") {
+                displayedString = tr("%1 has joined the conversation.").arg(from);
+            } else if (action == "remove") {
+                displayedString = tr("%1 has left the conversation.").arg(from);
+            }
+        } else if (interaction.type == interaction::Type::DATA_TRANSFER) {
+            displayedString = from + ": " + interaction.commit.value("displayName");
+        } else {
+            displayedString = from + ": " + interaction.body;
         }
 
         auto preferences = accountInfo.conversationModel->getConversationPreferences(convUid);
@@ -192,7 +200,7 @@ ConversationsAdapter::onNewUnreadInteraction(const QString& accountId,
         auto notifId = QString("%1;%2;%3").arg(accountId, convUid, interactionId);
         systemTray_->showNotification(notifId,
                                       tr("%1 received a new message").arg(to),
-                                      from + ": " + body_,
+                                      displayedString,
                                       SystemTray::NotificationType::CHAT,
                                       Utils::QImageToByteArray(contactPhoto));
 
@@ -246,8 +254,8 @@ ConversationsAdapter::onNewTrustRequest(const QString& accountId,
             auto contactPhoto = Utils::contactPhoto(lrcInstance_, peerUri, QSize(50, 50), accountId);
             auto notifId = QString("%1;%2").arg(accountId, conv);
             systemTray_->showNotification(notifId,
-                                          tr("%1 received a new trust request").arg(to),
-                                          "New request from " + peerBestName,
+                                          tr("%1 received a new invitation").arg(to),
+                                          "New invitation from " + peerBestName,
                                           SystemTray::NotificationType::REQUEST,
                                           Utils::QImageToByteArray(contactPhoto));
         };
@@ -260,10 +268,11 @@ ConversationsAdapter::onNewTrustRequest(const QString& accountId,
                               this,
                               [this, accountId, peerUri, cb](NameDirectory::LookupStatus status,
                                                              const QString& address,
-                                                             const QString& name) {
+                                                             const QString& registeredName,
+                                                             const QString& requestedName) {
                                   if (address == peerUri) {
                                       if (status == NameDirectory::LookupStatus::SUCCESS)
-                                          cb(name);
+                                          cb(registeredName);
                                       else {
                                           auto& accInfo = lrcInstance_->getAccountInfo(accountId);
                                           cb(accInfo.contactModel->bestNameForContact(peerUri));
