@@ -1,9 +1,5 @@
 /*
- * Copyright (C) 2015-2024 Savoir-faire Linux Inc.
- * Author: Edric Ladent Milaret <edric.ladent-milaret@savoirfairelinux.com>
- * Author: Andreas Traczyk <andreas.traczyk@savoirfairelinux.com>
- * Author: Mingrui Zhang <mingrui.zhang@savoirfairelinux.com>
- * Author: Aline Gondim Santos <aline.gondimsantos@savoirfairelinux.com>
+ * Copyright (C) 2015-2025 Savoir-faire Linux Inc.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -27,6 +23,7 @@
 #include "connectivitymonitor.h"
 #include "systemtray.h"
 #include "previewengine.h"
+#include "crashreporter.h"
 
 #include <QWKQuick/qwkquickglobal.h>
 
@@ -42,8 +39,6 @@
 #include <QLibraryInfo>
 #include <QQuickWindow>
 
-#include <thread>
-
 #ifdef Q_OS_WIN
 #include <windows.h>
 #endif
@@ -159,6 +154,9 @@ MainApplication::MainApplication(int& argc, char** argv)
                                      "libclient.debug=false\n"
                                      "qt.*=false\n"
                                      "qml.debug=false\n"
+                                     "default.debug=false\n"
+                                     "client.debug=false\n"
+                                     "spellcheck.debug=false\n"
                                      "\n");
     // These can be set in the environment as well.
     // e.g. QT_LOGGING_RULES="*.debug=false;qml.debug=true"
@@ -178,19 +176,27 @@ MainApplication::~MainApplication()
 {
     engine_.reset();
     lrcInstance_.reset();
+
+    // Allow the crash reporter to do implementation-specific cleanup before the application exits.
+    delete crashReporter_;
 }
 
 bool
 MainApplication::init()
 {
+    // Let's make sure we can provide postmortem debugging information prior
+    // to any other initialization. This won't do anything if crashpad isn't
+    // enabled.
+    settingsManager_ = new AppSettingsManager(this);
+    crashReporter_ = new CrashReporter(settingsManager_, this);
+
     // This 2-phase initialisation prevents ephemeral instances from
-    // performing unnecessary tasks, like initializing the webengine.
+    // performing unnecessary tasks, like initializing the WebEngine.
     engine_.reset(new QQmlApplicationEngine(this));
 
     QWK::registerTypes(engine_.get());
 
     connectivityMonitor_ = new ConnectivityMonitor(this);
-    settingsManager_ = new AppSettingsManager(this);
     systemTray_ = new SystemTray(settingsManager_, this);
     previewEngine_ = new PreviewEngine(connectivityMonitor_, this);
 
@@ -339,8 +345,8 @@ MainApplication::parseArguments()
     parser_.addOption(muteDaemonOption);
 
 #ifdef QT_DEBUG
-    // In debug mode, add an option to test a specific QML component via its name.
-    // e.g. ./jami --test AccountComboBox
+    //  In debug mode, add an option to test a specific QML component via its name.
+    //  e.g. ./jami --test AccountComboBox
     parser_.addOption(QCommandLineOption("test", "Test a QML component via its name.", "uri"));
     // We may need to force the test window dimensions in the case that the component to test
     // does not specify its own dimensions and is dependent on parent/sibling dimensions.
@@ -420,7 +426,11 @@ MainApplication::initQmlLayer()
                          &screenInfo_,
                          this);
 
-    QUrl url;
+    // Register the crash reporter as a context property in the QML engine.
+    engine_->rootContext()->setContextProperty("crashReporter", crashReporter_);
+
+    QUrl url = QStringLiteral("qrc:/MainApplicationWindow.qml");
+#ifdef QT_DEBUG
     if (parser_.isSet("test")) {
         // List the QML files in the project source tree.
         const auto targetTestComponent = findResource(parser_.value("test"));
@@ -433,10 +443,9 @@ MainApplication::initQmlLayer()
         const auto testHeight = parser_.isSet("height") ? parser_.value("height").toInt() : 0;
         engine_->rootContext()->setContextProperty("testWidth", testWidth);
         engine_->rootContext()->setContextProperty("testHeight", testHeight);
-        url = u"qrc:/ComponentTestWindow.qml"_qs;
-    } else {
-        url = u"qrc:/MainApplicationWindow.qml"_qs;
+        url = QStringLiteral("qrc:/ComponentTestWindow.qml");
     }
+#endif
     QObject::connect(
         engine_.get(),
         &QQmlApplicationEngine::objectCreationFailed,
@@ -446,13 +455,13 @@ MainApplication::initQmlLayer()
     engine_->load(url);
 
     // Report the render interface used.
-    C_DBG << "Main window loaded using" << getRenderInterfaceString();
+    C_INFO << "Main window loaded using" << getRenderInterfaceString();
 }
 
 void
 MainApplication::initSystray()
 {
-    systemTray_->setIcon(QIcon(":/images/jami.svg"));
+    systemTray_->setIcon(QIcon(":/images/net.jami.Jami.svg"));
 
     QMenu* menu {nullptr};
     // If there was a previous menu, reuse it, otherwise create a new one.
