@@ -1,11 +1,5 @@
 /*
- * Copyright (C) 2020-2024 Savoir-faire Linux Inc.
- * Author: Edric Ladent Milaret <edric.ladent-milaret@savoirfairelinux.com>
- * Author: Anthony Léonard <anthony.leonard@savoirfairelinux.com>
- * Author: Olivier Soldano <olivier.soldano@savoirfairelinux.com>
- * Author: Andreas Traczyk <andreas.traczyk@savoirfairelinux.com>
- * Author: Isa Nanic <isa.nanic@savoirfairelinux.com>
- * Author: Mingrui Zhang <mingrui.zhang@savoirfairelinux.com>
+ * Copyright (C) 2020-2025 Savoir-faire Linux Inc.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -165,6 +159,16 @@ MessagesAdapter::sendMessage(const QString& message)
     }
 }
 
+void
+MessagesAdapter::sendMessageToUid(const QString& message, const QString& convUid)
+{
+    try {
+        lrcInstance_->getCurrentConversationModel()->sendMessage(convUid, message, replyToId_);
+    } catch (...) {
+        qDebug() << "Exception during sendMessage:" << message;
+    }
+}
+
 void
 MessagesAdapter::editMessage(const QString& convId, const QString& newBody, const QString& messageId)
 {
@@ -221,6 +225,21 @@ MessagesAdapter::sendFile(const QString& message)
     }
 }
 
+void
+MessagesAdapter::sendFileToUid(const QString& message, const QString& convUid)
+{
+    QFileInfo fi(message);
+    QString fileName = fi.fileName();
+    try {
+        lrcInstance_->getCurrentConversationModel()->sendFile(convUid,
+                                                              message,
+                                                              fileName,
+                                                              replyToId_);
+    } catch (...) {
+        qDebug() << "Exception during sendFile";
+    }
+}
+
 void
 MessagesAdapter::joinCall(const QString& uri,
                           const QString& deviceId,
@@ -312,8 +331,7 @@ MessagesAdapter::onPaste()
         QString path = QDir::temp().filePath(fileName);
 
         if (!pixmap.save(path, "PNG")) {
-            qDebug().noquote() << "Errors during QPixmap save"
-                               << "\n";
+            qDebug().noquote() << "Errors during QPixmap save" << "\n";
             return;
         }
 
@@ -335,40 +353,6 @@ MessagesAdapter::onPaste()
     }
 }
 
-QString
-MessagesAdapter::getStatusString(int status)
-{
-    switch (static_cast<interaction::Status>(status)) {
-    case interaction::Status::SENDING:
-        return QObject::tr("Sending");
-    case interaction::Status::FAILURE:
-        return QObject::tr("Failure");
-    case interaction::Status::SUCCESS:
-        return QObject::tr("Sent");
-    case interaction::Status::TRANSFER_CREATED:
-        return QObject::tr("Connecting");
-    case interaction::Status::TRANSFER_ACCEPTED:
-        return QObject::tr("Accept");
-    case interaction::Status::TRANSFER_CANCELED:
-        return QObject::tr("Canceled");
-    case interaction::Status::TRANSFER_ERROR:
-    case interaction::Status::TRANSFER_UNJOINABLE_PEER:
-        return QObject::tr("Unable to make contact");
-    case interaction::Status::TRANSFER_ONGOING:
-        return QObject::tr("Ongoing");
-    case interaction::Status::TRANSFER_AWAITING_PEER:
-        return QObject::tr("Waiting for contact");
-    case interaction::Status::TRANSFER_AWAITING_HOST:
-        return QObject::tr("Incoming transfer");
-    case interaction::Status::TRANSFER_TIMEOUT_EXPIRED:
-        return QObject::tr("Timed out waiting for contact");
-    case interaction::Status::TRANSFER_FINISHED:
-        return QObject::tr("Finished");
-    default:
-        return {};
-    }
-}
-
 QVariantMap
 MessagesAdapter::getTransferStats(const QString& msgId, int status)
 {
@@ -496,10 +480,10 @@ MessagesAdapter::clearConversationHistory(const QString& accountId, const QStrin
 }
 
 void
-MessagesAdapter::removeConversation(const QString& convUid)
+MessagesAdapter::removeConversation(const QString& convUid, bool keepContact)
 {
     auto& accInfo = lrcInstance_->getCurrentAccountInfo();
-    accInfo.conversationModel->removeConversation(convUid);
+    accInfo.conversationModel->removeConversation(convUid, false, keepContact);
 }
 
 void
@@ -682,7 +666,7 @@ MessagesAdapter::getFormattedTime(const quint64 timestamp)
         timeLocale = curLocal.toString(curTime, curLocal.ShortFormat).toLower();
         return timeLocale;
     }
-    return QObject::tr("just now");
+    return QObject::tr("Just now");
 }
 
 QString
