@@ -1,10 +1,5 @@
-/*!
- * Copyright (C) 2015-2024 Savoir-faire Linux Inc.
- * Author: Edric Ladent Milaret <edric.ladent-milaret@savoirfairelinux.com>
- * Author: Andreas Traczyk <andreas.traczyk@savoirfairelinux.com>
- * Author: Isa Nanic <isa.nanic@savoirfairelinux.com
- * Author: Mingrui Zhang <mingrui.zhang@savoirfairelinux.com>
- * Author: Aline Gondim Santos <aline.gondimsantos@savoirfairelinux.com>
+/*
+ * Copyright (C) 2015-2025 Savoir-faire Linux Inc.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -24,6 +19,7 @@
 
 #include "jamiavatartheme.h"
 #include "lrcinstance.h"
+#include "global.h"
 
 #include <api/contact.h>
 
@@ -75,7 +71,7 @@ Utils::remove_argument(char** argv,
         }
     });
 
-    // If any occurrences were removed...
+    // If any occurrences were removed…
     if (new_end != argv + argc) {
         // Adjust the argument count.
         argc = std::distance(argv, new_end);
@@ -86,7 +82,7 @@ void
 Utils::testVulkanSupport()
 {
 #if defined(Q_OS_WIN)
-    // Checks Vulkan support using the vulkan functions loaded directly
+    // Checks Vulkan support using the Vulkan functions loaded directly
     // from vulkan-1.dll.
     struct DllLoader
     {
@@ -94,7 +90,7 @@ Utils::testVulkanSupport()
             : module(LoadLibraryA(filename.c_str()))
         {
             if (module == nullptr) {
-                throw std::runtime_error("Can't load module.");
+                throw std::runtime_error("Unable to load module.");
             }
         }
         ~DllLoader()
@@ -122,7 +118,7 @@ Utils::testVulkanSupport()
     int VkInstanceCreateInfo[16] = {1};
     auto result = vkCreateInstance(VkInstanceCreateInfo, 0, &instance);
     if (!instance || result != 0) {
-        throw std::runtime_error("Can't create Vulkan instance.");
+        throw std::runtime_error("Unable to create Vulkan instance.");
     }
 #endif
 }
@@ -154,9 +150,9 @@ Utils::CreateStartupLink(const std::wstring& wstrAppName)
 
 #ifdef JAMI_INSTALL_PREFIX
     desktopPath = JAMI_INSTALL_PREFIX;
-    desktopPath += "/jami/jami.desktop";
+    desktopPath += "/jami/net.jami.Jami.desktop";
 #else
-    desktopPath = "share/jami/jami.desktop";
+    desktopPath = "share/jami/net.jami.Jami.desktop";
     QStringList paths = {"/usr/" + desktopPath,
                          "/usr/local/" + desktopPath,
                          QDir::currentPath() + "/../../install/client-qt/" + desktopPath};
@@ -169,14 +165,14 @@ Utils::CreateStartupLink(const std::wstring& wstrAppName)
 #endif
 
     if (desktopPath.isEmpty() || !(QFile::exists(desktopPath))) {
-        qDebug() << "Could not locate .desktop file at" << desktopPath;
+        qDebug() << "Error while attempting to locate .desktop file at" << desktopPath;
         return false;
     }
 
     qDebug() << "Linking autostart file from" << desktopPath;
 
     QString desktopFile = QStandardPaths::locate(QStandardPaths::ConfigLocation,
-                                                 "autostart/jami.desktop");
+                                                 "autostart/net.jami.Jami.desktop");
     if (!desktopFile.isEmpty()) {
         QFileInfo symlinkInfo(desktopFile);
         if (symlinkInfo.isSymLink()) {
@@ -196,17 +192,17 @@ Utils::CreateStartupLink(const std::wstring& wstrAppName)
             if (QDir().mkdir(autoStartDir)) {
                 qDebug() << "Created autostart directory:" << autoStartDir;
             } else {
-                qWarning() << "Could not create autostart directory:" << autoStartDir;
+                qWarning() << "Error while creating autostart directory:" << autoStartDir;
                 return false;
             }
         }
-        desktopFile = autoStartDir + "/jami.desktop";
+        desktopFile = autoStartDir + "/net.jami.Jami.desktop";
     }
 
     QFile srcFile(desktopPath);
     bool result = srcFile.link(desktopFile);
     qDebug() << desktopFile
-             << (result ? "-> " + desktopPath + " successfully created" : "could not be created");
+             << (result ? "-> " + desktopPath + " created successfully" : "unable to be created");
     return result;
 #endif
 }
@@ -258,13 +254,13 @@ Utils::DeleteStartupLink(const std::wstring& wstrAppName)
 #else
     Q_UNUSED(wstrAppName)
     QString desktopFile = QStandardPaths::locate(QStandardPaths::ConfigLocation,
-                                                 "autostart/jami.desktop");
+                                                 "autostart/net.jami.Jami.desktop");
     if (!desktopFile.isEmpty()) {
         try {
             QFile::remove(desktopFile);
             qDebug() << "Autostart disabled," << desktopFile << "removed";
         } catch (...) {
-            qDebug() << "Could not remove" << desktopFile;
+            qDebug() << "Unable to remove" << desktopFile;
         }
     } else {
         qDebug() << desktopFile << "does not exist";
@@ -285,7 +281,8 @@ Utils::CheckStartupLink(const std::wstring& wstrAppName)
 #else
     Q_UNUSED(wstrAppName)
     return (
-        !QStandardPaths::locate(QStandardPaths::ConfigLocation, "autostart/jami.desktop").isEmpty());
+        !QStandardPaths::locate(QStandardPaths::ConfigLocation, "autostart/net.jami.Jami.desktop")
+             .isEmpty());
 #endif
 }
 
@@ -299,7 +296,7 @@ Utils::removeOldVersions()
      * remove 1. the configuration reg keys for Ring-x64, 2. the startup links for Ring,
      * 3. the winsparkle reg keys. The NSIS uninstall reg keys for Jami-x64 are removed
      * by the MSI installer.
-     * Uninstallation of Ring, either 32 or 64 bit, is left to the user.
+     * Uninstallation of Ring, either 32-bit or 64-bit, is left to the user.
      * The current version of Jami will attempt to kill Ring.exe upon start if a startup
      * link is found.
      */
@@ -419,8 +416,14 @@ Utils::contactPhoto(LRCInstance* instance,
     try {
         auto& accInfo = instance->accountModel().getAccountInfo(
             accountId.isEmpty() ? instance->get_currentAccountId() : accountId);
-        auto contactInfo = accInfo.contactModel->getContact(contactUri);
         auto contactPhoto = accInfo.contactModel->avatar(contactUri);
+        if (!contactPhoto.isEmpty()) {
+            photo = imageFromBase64String(contactPhoto);
+            if (!photo.isNull())
+                return Utils::scaleAndFrame(photo, size);
+        }
+        // If no avatar is found, generate one
+        auto contactInfo = accInfo.contactModel->getContact(contactUri);
         auto bestName = accInfo.contactModel->bestNameForContact(contactUri);
         if (accInfo.profileInfo.type == profile::Type::SIP
             && contactInfo.profileInfo.type == profile::Type::TEMPORARY) {
@@ -428,12 +431,6 @@ Utils::contactPhoto(LRCInstance* instance,
         } else if (contactInfo.profileInfo.type == profile::Type::TEMPORARY
                    && contactInfo.profileInfo.uri.isEmpty()) {
             photo = Utils::fallbackAvatar(QString(), QString());
-        } else if (!contactPhoto.isEmpty()) {
-            photo = imageFromBase64String(contactPhoto);
-            if (photo.isNull()) {
-                auto avatarName = contactInfo.profileInfo.uri == bestName ? QString() : bestName;
-                photo = Utils::fallbackAvatar("jami:" + contactInfo.profileInfo.uri, avatarName);
-            }
         } else {
             auto avatarName = contactInfo.profileInfo.uri == bestName ? QString() : bestName;
             photo = Utils::fallbackAvatar("jami:" + contactInfo.profileInfo.uri, avatarName);
@@ -464,7 +461,7 @@ Utils::conversationAvatar(LRCInstance* instance,
             if (!photo.isNull()) {
                 return scaleAndFrame(photo, size);
             }
-            qWarning() << "Couldn't load image from base 64 data for conversation " << convId;
+            qWarning() << "Unable to load image from Base64 data for conversation " << convId;
         }
         // Else, generate an avatar
         auto members = convModel->peersForConversation(convId);
@@ -488,7 +485,7 @@ Utils::conversationAvatar(LRCInstance* instance,
         painter.drawImage(avatar.rect(), peerAAvatar);
         painter.drawImage(avatar.rect(), peerBAvatar);
     } catch (const std::exception& e) {
-        qDebug() << Q_FUNC_INFO << e.what();
+        C_DBG << e.what();
     }
     return avatar;
 }
@@ -539,13 +536,20 @@ Utils::getCirclePhoto(const QImage original, int sizePhoto)
                                    Qt::KeepAspectRatioByExpanding,
                                    Qt::SmoothTransformation)
                            .convertToFormat(QImage::Format_ARGB32_Premultiplied);
-    int margin = 0;
+    int marginX = 0;
+    int marginY = 0;
+
     if (scaledPhoto.width() > sizePhoto) {
-        margin = (scaledPhoto.width() - sizePhoto) / 2;
+        marginX = (scaledPhoto.width() - sizePhoto) / 2;
     }
+    if (scaledPhoto.height() > sizePhoto) {
+        marginY = (scaledPhoto.height() - sizePhoto) / 2;
+    }
+
     painter.drawEllipse(0, 0, sizePhoto, sizePhoto);
     painter.setCompositionMode(QPainter::CompositionMode_SourceIn);
-    painter.drawImage(0, 0, scaledPhoto, margin, 0);
+    painter.drawImage(0, 0, scaledPhoto, marginX, marginY);
+
     return target;
 }
 
@@ -611,7 +615,27 @@ Utils::getProjectCredits()
         return {};
     }
     QTextStream in(&projectCreditsFile);
-    return in.readAll();
+    return in.readAll().arg(QObject::tr("We would like to thank our contributors, whose efforts "
+                                        "over many years have made this software what it is."),
+                            QObject::tr("Developers"),
+                            QObject::tr("Media"),
+                            QObject::tr("Community Management"),
+                            QObject::tr("Special thanks to"),
+                            QObject::tr(
+                                "This is a list of people who have made a significant investment "
+                                "of time, with useful results, into Jami. Any such contributors "
+                                "who want to be added to the list should contact us."));
+}
+
+QString
+Utils::getAvailableDictionariesJson()
+{
+    QFile availableDictionariesFile(":/misc/available_dictionaries.json");
+    if (!availableDictionariesFile.open(QIODevice::ReadOnly | QIODevice::Text)) {
+        qDebug().noquote() << "Available Dictionaries file failed to load";
+        return {};
+    }
+    return QString(availableDictionariesFile.readAll());
 }
 
 inline QString
@@ -851,7 +875,7 @@ Utils::QByteArrayFromFile(const QString& filename)
     if (file.open(QIODevice::ReadOnly)) {
         return file.readAll();
     }
-    qDebug() << "QByteArrayFromFile: can't open file" << filename;
+    qDebug() << "QByteArrayFromFile: unable to open file" << filename;
     return {};
 }
 
@@ -939,3 +963,13 @@ Utils::getTempSwarmAvatarPath()
     return QStandardPaths::writableLocation(QStandardPaths::CacheLocation) + QDir::separator()
            + "tmpSwarmImage";
 }
+
+QVariantMap
+Utils::mapStringStringToVariantMap(const MapStringString& map)
+{
+    QVariantMap variantMap;
+    for (auto it = map.constBegin(); it != map.constEnd(); ++it) {
+        variantMap.insert(it.key(), it.value());
+    }
+    return variantMap;
+}
