@@ -1,10 +1,5 @@
-/*!
- * Copyright (C) 2015-2024 Savoir-faire Linux Inc.
- * Author: Edric Ladent Milaret <edric.ladent-milaret@savoirfairelinux.com>
- * Author: Andreas Traczyk <andreas.traczyk@savoirfairelinux.com>
- * Author: Isa Nanic <isa.nanic@savoirfairelinux.com>
- * Author: Mingrui Zhang   <mingrui.zhang@savoirfairelinux.com>
- * Author: Aline Gondim Santos   <aline.gondimsantos@savoirfairelinux.com>
+/*
+ * Copyright (C) 2015-2025 Savoir-faire Linux Inc.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -25,8 +20,8 @@
 #include "lrcinstance.h"
 #include "systemtray.h"
 #include "utils.h"
-#include "version.h"
-
+#include "version_info.h"
+#include "global.h"
 #include <api/datatransfermodel.h>
 #include <api/contact.h>
 
@@ -96,11 +91,17 @@ UtilsAdapter::setAppValue(const Settings::Key key, const QVariant& value)
         Q_EMIT appThemeChanged();
     else if (key == Settings::Key::UseFramelessWindow)
         Q_EMIT useFramelessWindowChanged();
+    else if (key == Settings::Key::SpellLang)
+        Q_EMIT spellLanguageChanged();
+    else if (key == Settings::Key::EnableSpellCheck)
+        Q_EMIT enableSpellCheckChanged();
+    else if (key == Settings::Key::RaiseWhenCalled)
+        Q_EMIT raiseWhenCalledChanged();
 #if !APPSTORE
     // Any donation campaign-related keys can trigger a donation campaign check
     else if (key == Settings::Key::IsDonationVisible
-             || key == Settings::Key::Donation2023VisibleDate
-             || key == Settings::Key::Donation2023EndDate2)
+             || key == Settings::Key::Donation2025StartDate
+             || key == Settings::Key::Donation2025EndDate)
         Q_EMIT donationCampaignSettingsChanged();
 #endif
 }
@@ -123,10 +124,16 @@ UtilsAdapter::getProjectCredits()
     return Utils::getProjectCredits();
 }
 
+const QString
+UtilsAdapter::getBuildIDStr()
+{
+    return BUILD_VERSION_STRING;
+}
+
 const QString
 UtilsAdapter::getVersionStr()
 {
-    return QString(VERSION_STRING);
+    return APP_VERSION_STRING + "." + CORE_VERSION_STRING;
 }
 
 void
@@ -229,7 +236,7 @@ UtilsAdapter::getConvIdForUri(const QString& accountId, const QString& uri)
             return {};
         return convInfo->get().uid;
     } catch (const std::out_of_range& e) {
-        qDebug() << e.what();
+        C_DBG << e.what();
         return "";
     }
 }
@@ -242,7 +249,7 @@ UtilsAdapter::getPeerUri(const QString& accountId, const QString& uid)
         const auto& convInfo = convModel->getConversationForUid(uid).value();
         return convInfo.get().participants.front().uri;
     } catch (const std::out_of_range& e) {
-        qDebug() << e.what();
+        C_DBG << e.what();
         return "";
     }
 }
@@ -745,7 +752,7 @@ UtilsAdapter::isSystemThemeDark()
 #endif
     return readAppsUseLightThemeRegistry(true);
 #else
-    qWarning("System theme detection is not implemented or is not supported");
+    C_WARN << "System theme detection is not implemented or is not supported";
     return false;
 #endif // WIN32
 #endif // __has_include(<gio/gio.h>)
@@ -808,18 +815,20 @@ UtilsAdapter::isRTL()
     pref = pref == "SYSTEM" ? QLocale::system().name() : pref;
     static const QStringList rtlLanguages {
         // as defined by ISO 639-1
-        "ar", // Arabic
-        "he", // Hebrew
-        "fa", // Persian (Farsi)
-        "ur", // Urdu
-        "ps", // Pashto
-        "ku", // Kurdish
-        "sd", // Sindhi
-        "dv", // Dhivehi (Maldivian)
-        "yi", // Yiddish
-        "am", // Amharic
-        "ti", // Tigrinya
-        "kk"  // Kazakh (in Arabic script)
+        "ar",    // Arabic
+        "he",    // Hebrew
+        "fa",    // Persian (Farsi)
+        "az_IR", // Azerbaijani
+        "ur",    // Urdu
+        "ps",    // Pashto
+        "ku",    // Kurdish
+        "sd",    // Sindhi
+        "dv",    // Dhivehi (Maldivian)
+        "yi",    // Yiddish
+        "am",    // Amharic
+        "ti"     // Tigrinya
+        // Since we haven't requested the Arabic script of Kazakh in Transifex, we cannot include it here.
+        // However we have the Cyrillic script of Kazakh which is LTR (code: "kk").
     };
     return rtlLanguages.contains(pref);
 }
@@ -827,13 +836,7 @@ UtilsAdapter::isRTL()
 bool
 UtilsAdapter::isSystemTrayIconVisible()
 {
-    if (!systemTray_)
-        return false;
-    // https://bugreports.qt.io/browse/QTBUG-118656
-#if defined(Q_OS_LINUX) && !defined(Q_OS_ANDROID)
-    return true;
-#endif
-    return systemTray_->geometry() != QRect();
+    return QSystemTrayIcon::isSystemTrayAvailable() && systemTray_;
 }
 
 QString
@@ -891,7 +894,7 @@ UtilsAdapter::createDummyImage() const
         qInfo() << "Dummy image created" << QDir::tempPath() + "/dummy.png";
         return QDir::tempPath() + "/dummy.png";
     } else {
-        qWarning() << "Could not create dummy image";
+        C_WARN << "An error occurred while creating dummy image.";
         return "";
     }
 }
