@@ -1,7 +1,5 @@
 /****************************************************************************
- *    Copyright (C) 2017-2024 Savoir-faire Linux Inc.                       *
- *   Author: Nicolas Jäger <nicolas.jager@savoirfairelinux.com>             *
- *   Author: Sébastien Blin <sebastien.blin@savoirfairelinux.com>           *
+ *   Copyright (C) 2017-2025 Savoir-faire Linux Inc.                        *
  *                                                                          *
  *   This library is free software; you can redistribute it and/or          *
  *   modify it under the terms of the GNU Lesser General Public             *
@@ -73,7 +71,7 @@ struct AccountConversation
 typedef QVector<QVector<AccountConversation>> ConferenceableValue;
 
 /**
- *  @brief Class that manages conversation informations.
+ *  @brief Class that manages conversation information.
  */
 class LIB_EXPORT ConversationModel : public QObject
 {
@@ -193,8 +191,9 @@ public:
      * Remove a conversation and the contact if it's a dialog
      * @param uid of the conversation
      * @param banned if we want to ban the contact.
+     * @param keepContact if we want to keep the contact. New conversation could be created
      */
-    void removeConversation(const QString& uid, bool banned = false);
+    void removeConversation(const QString& uid, bool banned = false,  bool keepContact = false);
     /**
      * Get the action wanted by the user when they click on the conversation
      * @param uid of the conversation
