@@ -1,9 +1,5 @@
 /****************************************************************************
- *    Copyright (C) 2017-2024 Savoir-faire Linux Inc.                       *
- *   Author: Nicolas Jäger <nicolas.jager@savoirfairelinux.com>             *
- *   Author: Sébastien Blin <sebastien.blin@savoirfairelinux.com>           *
- *   Author: Kateryna Kostiuk <kateryna.kostiuk@savoirfairelinux.com>       *
- *   Author: Andreas Traczyk <andreas.traczyk@savoirfairelinux.com>         *
+ *   Copyright (C) 2017-2025 Savoir-faire Linux Inc.                        *
  *                                                                          *
  *   This library is free software; you can redistribute it and/or          *
  *   modify it under the terms of the GNU Lesser General Public             *
@@ -482,14 +478,7 @@ beginConversationWithPeer(Database& db,
     db.insertInto("conversations",
                   {{":id", "id"}, {":participant", "participant"}},
                   {{":id", newConversationsId}, {":participant", peer_uri}});
-    api::interaction::Info msg {isOutgoing ? "" : peer_uri,
-                                {},
-                                timestamp ? timestamp : std::time(nullptr),
-                                0,
-                                api::interaction::Type::CONTACT,
-                                isOutgoing ? api::interaction::Status::SUCCESS
-                                           : api::interaction::Status::UNKNOWN,
-                                isOutgoing};
+    api::interaction::Info msg = api::interaction::Info::contact(isOutgoing ? "" : peer_uri, timestamp);
     // Add first interaction
     addMessageToConversation(db, newConversationsId, msg);
     return newConversationsId;
@@ -696,9 +685,9 @@ updateDataTransferInteractionForDaemonId(Database& db,
         return;
     }
     auto body = result[0];
-    auto status = api::interaction::to_status(result[1]);
+    auto status = api::interaction::to_transferStatus(result[1]);
     interaction.body = body;
-    interaction.status = status;
+    interaction.transferStatus = status;
 }
 
 QString
@@ -731,6 +720,16 @@ updateInteractionStatus(Database& db, const QString& id, api::interaction::Statu
               {{":id", id}});
 }
 
+void
+updateInteractionTransferStatus(Database& db, const QString& id, api::interaction::TransferStatus newStatus)
+{
+    db.update("interactions",
+              {"status=:status"},
+              {{":status", api::interaction::to_string(newStatus)}},
+              "id=:id",
+              {{":id", id}});
+}
+
 void
 setInteractionRead(Database& db, const QString& id)
 {
