@@ -1,7 +1,5 @@
 /*
- *  Copyright (C) 2018-2024 Savoir-faire Linux Inc.
- *  Author: Hugo Lefeuvre <hugo.lefeuvre@savoirfairelinux.com>
- *  Author: Sébastien Blin <sebastien.blin@savoirfairelinux.com>
+ *  Copyright (C) 2018-2025 Savoir-faire Linux Inc.
  *
  *  This library is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU Lesser General Public
@@ -25,6 +23,8 @@
 #include "directrenderer.h"
 #else
 #include "shmrenderer.h"
+#include <csignal>
+#include <thread>
 #endif
 #include "callbackshandler.h"
 #include "dbus/callmanager.h"
@@ -42,11 +42,7 @@
 
 #include <algorithm> // std::sort
 #include <chrono>
-#include <csignal>
 #include <iomanip> // for std::put_time
-#include <fstream>
-#include <mutex>
-#include <thread>
 #include <string>
 #include <sstream>
 
@@ -328,7 +324,7 @@ void
 AVModel::setDeviceSettings(video::Settings& settings)
 {
     MapStringString newSettings;
-    auto rate = QString::number(settings.rate, 'f', 7);
+    auto rate = QString::number(static_cast<double>(settings.rate), 'f', 7);
     rate = rate.left(rate.length() - 1);
     newSettings["channel"] = settings.channel;
     newSettings["name"] = settings.name;
@@ -357,7 +353,7 @@ AVModel::getDeviceIdFromName(const QString& deviceName) const
         return settings.name == deviceName;
     });
     if (iter == devices.end()) {
-        qWarning() << "Couldn't find device: " << deviceName;
+        LC_WARN << "Unable to find device: " << deviceName;
         return {};
     }
     return *iter;
@@ -491,7 +487,7 @@ void
 AVModel::stopLocalRecorder(const QString& path) const
 {
     if (path.isEmpty()) {
-        qWarning("stopLocalRecorder: can't stop non existing recording");
+        LC_WARN << "stopLocalRecorder: unable to stop non existing recording";
         return;
     }
 
@@ -664,7 +660,7 @@ AVModel::getListWindows() const
                                                                      });
 
     if (xcb_connection_has_error(c.get())) {
-        qDebug() << "xcb connection has error";
+        LC_DBG << "xcb connection has error";
         return ret;
     }
 
@@ -690,7 +686,7 @@ AVModel::getListWindows() const
     propertyPtr replyPropList(xcb_get_property_reply(c.get(), propCookieList, &e),
                               [](auto* ptr) { free(ptr); });
     if (e) {
-        qDebug() << "Error: " << e->error_code;
+        LC_DBG << "Error: " << e->error_code;
         free(e);
     }
     if (replyPropList.get()) {
@@ -710,7 +706,7 @@ AVModel::getListWindows() const
                                            free(ptr);
                                        }};
                 if (e) {
-                    qDebug() << "Error: " << e->error_code;
+                    LC_DBG << "Error: " << e->error_code;
                     free(e);
                 }
                 if (replyProp.get()) {
@@ -987,7 +983,7 @@ AVModelPimpl::getDevice(int type) const
         if (deviceIdx < devices.size())
             result = devices.at(deviceIdx);
     } catch (std::bad_alloc& ba) {
-        qWarning() << "bad_alloc caught: " << ba.what();
+        LC_WARN << "bad_alloc caught: " << ba.what();
         return "";
     }
     return result;
@@ -1060,7 +1056,7 @@ AVModelPimpl::removeRenderer(const QString& id)
     QWriteLocker lk(&renderersMutex_);
     auto it = renderers_.find(id);
     if (it == renderers_.end()) {
-        qWarning() << "Cannot remove renderer. " << id << "not found";
+        LC_DBG << "Unable to remove renderer. " << id << " not found";
         return {};
     }
     auto removed = std::move(it->second);
