@@ -1,7 +1,5 @@
 /****************************************************************************
- *    Copyright (C) 2017-2024 Savoir-faire Linux Inc.                       *
- *   Author: Nicolas Jäger <nicolas.jager@savoirfairelinux.com>             *
- *   Author: Sébastien Blin <sebastien.blin@savoirfairelinux.com>           *
+ *   Copyright (C) 2017-2025 Savoir-faire Linux Inc.                        *
  *                                                                          *
  *   This library is free software; you can redistribute it and/or          *
  *   modify it under the terms of the GNU Lesser General Public             *
@@ -244,9 +242,15 @@ CallbacksHandler::CallbacksHandler(const Lrc& parent)
             Qt::QueuedConnection);
 
     connect(&ConfigurationManager::instance(),
-            &ConfigurationManagerInterface::exportOnRingEnded,
+            &ConfigurationManagerInterface::deviceAuthStateChanged,
             this,
-            &CallbacksHandler::slotExportOnRingEnded,
+            &CallbacksHandler::slotDeviceAuthStateChanged,
+            Qt::QueuedConnection);
+
+    connect(&ConfigurationManager::instance(),
+            &ConfigurationManagerInterface::addDeviceStateChanged,
+            this,
+            &CallbacksHandler::slotAddDeviceStateChanged,
             Qt::QueuedConnection);
 
     connect(&ConfigurationManager::instance(),
@@ -548,9 +552,11 @@ CallbacksHandler::slotIncomingMessage(const QString& accountId,
 }
 
 void
-CallbacksHandler::slotConferenceCreated(const QString& accountId, const QString& callId)
+CallbacksHandler::slotConferenceCreated(const QString& accountId,
+                                        const QString& convId,
+                                        const QString& callId)
 {
-    Q_EMIT conferenceCreated(accountId, callId);
+    Q_EMIT conferenceCreated(accountId, convId, callId);
 }
 
 void
@@ -663,14 +669,6 @@ CallbacksHandler::slotKnownDevicesChanged(const QString& accountId, const MapStr
     Q_EMIT knownDevicesChanged(accountId, devices);
 }
 
-void
-CallbacksHandler::slotDeviceRevokationEnded(const QString& accountId,
-                                            const QString& deviceId,
-                                            const int status)
-{
-    Q_EMIT deviceRevocationEnded(accountId, deviceId, status);
-}
-
 void
 CallbacksHandler::slotAccountProfileReceived(const QString& accountId,
                                              const QString& displayName,
@@ -680,9 +678,28 @@ CallbacksHandler::slotAccountProfileReceived(const QString& accountId,
 }
 
 void
-CallbacksHandler::slotExportOnRingEnded(const QString& accountId, int status, const QString& pin)
+CallbacksHandler::slotDeviceRevokationEnded(const QString& accountId,
+                                            const QString& deviceId,
+                                            const int status)
 {
-    Q_EMIT exportOnRingEnded(accountId, status, pin);
+    Q_EMIT deviceRevocationEnded(accountId, deviceId, status);
+}
+
+void
+CallbacksHandler::slotDeviceAuthStateChanged(const QString& accountId,
+                                             int state,
+                                             const MapStringString& details)
+{
+    Q_EMIT deviceAuthStateChanged(accountId, state, details);
+}
+
+void
+CallbacksHandler::slotAddDeviceStateChanged(const QString& accountId,
+                                            uint32_t operationId,
+                                            int state,
+                                            const MapStringString& details)
+{
+    Q_EMIT addDeviceStateChanged(accountId, operationId, state, details);
 }
 
 void
@@ -695,11 +712,12 @@ CallbacksHandler::slotNameRegistrationEnded(const QString& accountId,
 
 void
 CallbacksHandler::slotRegisteredNameFound(const QString& accountId,
+                                          const QString& requestedName,
                                           int status,
                                           const QString& address,
-                                          const QString& name)
+                                          const QString& registeredName)
 {
-    Q_EMIT registeredNameFound(accountId, status, address, name);
+    Q_EMIT registeredNameFound(accountId, requestedName, status, address, registeredName);
 }
 
 void
