@@ -1,7 +1,5 @@
 /****************************************************************************
- *    Copyright (C) 2017-2024 Savoir-faire Linux Inc.                       *
- *   Author: Nicolas Jäger <nicolas.jager@savoirfairelinux.com>             *
- *   Author: Sébastien Blin <sebastien.blin@savoirfairelinux.com>           *
+ *   Copyright (C) 2017-2025 Savoir-faire Linux Inc.                        *
  *                                                                          *
  *   This library is free software; you can redistribute it and/or          *
  *   modify it under the terms of the GNU Lesser General Public             *
@@ -173,7 +171,9 @@ Q_SIGNALS:
      * Connect this signal to know when a new conference is created
      * @param callId of the conference
      */
-    void conferenceCreated(const QString& accountId, const QString& callId);
+    void conferenceCreated(const QString& accountId,
+                           const QString& conversationId,
+                           const QString& callId);
     void conferenceChanged(const QString& accountId, const QString& confId, const QString& state);
     /**
      * Connect this signal to know when a conference is removed
@@ -237,12 +237,25 @@ Q_SIGNALS:
                                 const QString& userPhoto);
 
     /**
-     * Emit exportOnRingEnded
+     * Device authentication state has changed
      * @param accountId
-     * @param status SUCCESS = 0, WRONG_PASSWORD = 1, NETWORK_ERROR = 2
-     * @param pin
+     * @param state
+     * @param details map
      */
-    void exportOnRingEnded(const QString& accountId, int status, const QString& pin);
+    void deviceAuthStateChanged(const QString& accountId, int state, const MapStringString& details);
+
+    /**
+     * Add device state has changed
+     * @param accountId
+     * @param operationId
+     * @param state
+     * @param details map
+     */
+
+    void addDeviceStateChanged(const QString& accountId,
+                               uint32_t operationId,
+                               int state,
+                               const MapStringString& details);
 
     /**
      * Name registration has ended
@@ -255,13 +268,16 @@ Q_SIGNALS:
     /**
      * Name registration has been found
      * @param accountId
+     * @param requestedName the name requested
      * @param status
-     * @param name
+     * @param address
+     * @param registeredName the name found, have same normalized form as requestedName
      */
     void registeredNameFound(const QString& accountId,
+                             const QString& requestedName,
                              int status,
                              const QString& address,
-                             const QString& name);
+                             const QString& registeredName);
 
     /**
      * Migration ended
@@ -500,9 +516,12 @@ private Q_SLOTS:
     /**
      * Emit conferenceCreated
      * @param accountId
-     * @param callId of the conference
+     * @param callId         of the conference
+     * @param conversationId of the conference
      */
-    void slotConferenceCreated(const QString& accountId, const QString& callId);
+    void slotConferenceCreated(const QString& accountId,
+                               const QString& conversationId,
+                               const QString& callId);
     /**
      * Emit conferenceRemove
      * @param accountId
@@ -572,12 +591,26 @@ private Q_SLOTS:
                                     const QString& userPhoto);
 
     /**
-     * Emit exportOnRingEnded
+     * Device authentication state has changed
      * @param accountId
-     * @param status SUCCESS = 0, WRONG_PASSWORD = 1, NETWORK_ERROR = 2
-     * @param pin
+     * @param state
+     * @param details map
      */
-    void slotExportOnRingEnded(const QString& accountId, int status, const QString& pin);
+    void slotDeviceAuthStateChanged(const QString& accountId,
+                                    int state,
+                                    const MapStringString& details);
+
+    /**
+     * Add device state has changed
+     * @param accountId
+     * @param operationId
+     * @param state
+     * @param details map
+     */
+    void slotAddDeviceStateChanged(const QString& accountId,
+                                   uint32_t operationId,
+                                   int state,
+                                   const MapStringString& details);
 
     /**
      * Emit nameRegistrationEnded
@@ -590,13 +623,16 @@ private Q_SLOTS:
     /**
      * Emit registeredNameFound
      * @param accountId
+     * @param requestedName requested name
      * @param status
-     * @param name
+     * @param address
+     * @param registeredName found name, have same normalized form as requestedName
      */
     void slotRegisteredNameFound(const QString& accountId,
+                                 const QString& requestedName,
                                  int status,
                                  const QString& address,
-                                 const QString& name);
+                                 const QString& registeredName);
 
     /**
      * emit migrationEnded
