@@ -1,11 +1,5 @@
 /****************************************************************************
- *    Copyright (C) 2017-2024 Savoir-faire Linux Inc.                       *
- *   Author: Nicolas Jäger <nicolas.jager@savoirfairelinux.com>             *
- *   Author: Sébastien Blin <sebastien.blin@savoirfairelinux.com>           *
- *   Author: Guillaume Roguez <guillaume.roguez@savoirfairelinux.com>       *
- *   Author: Hugo Lefeuvre <hugo.lefeuvre@savoirfairelinux.com>             *
- *   Author: Kateryna Kostiuk <kateryna.kostiuk@savoirfairelinux.com>       *
- *   Author: Andreas Traczyk <andreas.traczyk@savoirfairelinux.com>         *
+ *   Copyright (C) 2017-2025 Savoir-faire Linux Inc.                        *
  *                                                                          *
  *   This library is free software; you can redistribute it and/or          *
  *   modify it under the terms of the GNU Lesser General Public             *
@@ -95,12 +89,12 @@ public:
     void searchSipContact(const URI& query);
 
     /**
-     * Update temporary item to display a given message about a given uri.
+     * Update temporary item to display a given message about a given URI.
      */
     void updateTemporaryMessage(const QString& mes);
 
     /**
-     * Check if equivalent uri exist in contact
+     * Check if equivalent URI exist in contact
      */
     QString sipUriReceivedFilter(const QString& uri);
 
@@ -133,6 +127,8 @@ public:
 
     // Store if a profile is cached for a given URI.
     QSet<QString> cachedProfiles;
+    // For non contacts (such as members of a group)
+    QMap<QString, profile::Info> cachedProfilesInfo;
 
 public Q_SLOTS:
     /**
@@ -162,11 +158,13 @@ public Q_SLOTS:
     /**
      * Listen CallbacksHandler when a registeredName is found
      * @param accountId account linked
+     * @param requestedName the name requested
      * @param status (0 = SUCCESS, 1 = Not found, 2 = Network error)
      * @param uri of the contact found
-     * @param registeredName of the contact found
+     * @param registeredName of the contact found, have same normalized form as requestedName
      */
     void slotRegisteredNameFound(const QString& accountId,
+                                 const QString& requestedName,
                                  int status,
                                  const QString& uri,
                                  const QString& registeredName);
@@ -237,6 +235,12 @@ ContactModel::ContactModel(const account::Info& owner,
 
 ContactModel::~ContactModel() {}
 
+void
+ContactModel::initContacts()
+{
+    pimpl_->fillWithJamiContacts();
+}
+
 const ContactModel::ContactInfoMap&
 ContactModel::getAllContacts() const
 {
@@ -438,7 +442,7 @@ ContactModel::searchContact(const QString& query)
 
     auto uriScheme = uri.schemeType();
     if (static_cast<int>(uriScheme) > 2 && owner.profileInfo.type == profile::Type::SIP) {
-        // sip account do not care if schemeType is NONE, or UNRECOGNIZED (enum value > 2)
+        // SIP account do not care if schemeType is NONE, or UNRECOGNIZED (enum value > 2)
         uriScheme = URI::SchemeType::SIP;
     } else if (uriScheme == URI::SchemeType::NONE && owner.profileInfo.type == profile::Type::JAMI) {
         uriScheme = URI::SchemeType::RING;
@@ -477,7 +481,7 @@ ContactModelPimpl::searchContact(const URI& query)
 
     if (query.protocolHint() == URI::ProtocolHint::RING) {
         updateTemporaryMessage("");
-        // no lookup, this is a ring infoHash
+        // No lookup, this is a ring infoHash
         for (auto& i : contacts)
             if (i.profileInfo.uri == uriId)
                 return;
@@ -552,10 +556,9 @@ ContactModel::bestNameForContact(const QString& contactUri) const
         return owner.accountModel->bestNameForAccount(owner.id);
     QString res = contactUri;
     try {
-        auto contact = getContact(contactUri);
         auto alias = displayName(contactUri).simplified();
         if (alias.isEmpty()) {
-            return bestIdFromContactInfo(contact);
+            return bestIdFromContactInfo(getContact(contactUri));
         }
         return alias;
     } catch (const std::out_of_range&) {
@@ -564,6 +567,16 @@ ContactModel::bestNameForContact(const QString& contactUri) const
             return *itContact;
         } else {
             // This is not a contact, but we should get the registered name
+            //
+            // NOTE: bestNameForContact is used by ConversationListModelBase::dataForItem,
+            // which means that it sometimes gets called multiple times within a short amount
+            // of time (less than a second), and can easily get called dozens or even hundreds
+            // of times in total after using Jami for a couple of hours. We don't want to send
+            // this many requests to the name server, so we store the peer's URI in nonContactLookup_.
+            // If the call to lookupAddress below succeeds, then the URI will be replaced by the
+            // peer's registered name, but in any case, this ensures that we don't do more than one
+            // lookup for a given peer, regardless of how many times bestNameForContact is called.
+            pimpl_->nonContactLookup_[contactUri] = contactUri;
             ConfigurationManager::instance().lookupAddress(owner.id, "", contactUri);
         }
     }
@@ -874,7 +887,11 @@ ContactModelPimpl::slotContactRemoved(const QString& accountId,
                 }
             }
             storage::removeContactConversations(db, contactUri);
-            storage::removeProfile(linked.owner.id, contactUri);
+            if (linked.owner.profileInfo.uri != contactUri) {
+                // Add check to not remove your own vcard if you're deleting
+                // a conversation with yourself.
+                storage::removeProfile(linked.owner.id, contactUri);
+            }
             contacts.remove(contactUri);
         }
     }
@@ -930,6 +947,7 @@ ContactModelPimpl::addToContacts(const QString& contactUri,
 
 void
 ContactModelPimpl::slotRegisteredNameFound(const QString& accountId,
+                                           const QString& requestedName,
                                            int status,
                                            const QString& uri,
                                            const QString& registeredName)
@@ -938,20 +956,21 @@ ContactModelPimpl::slotRegisteredNameFound(const QString& accountId,
         return;
 
     if (status == 0 /* SUCCESS */) {
+        QString foundName = registeredName.toLower();
         std::lock_guard<std::mutex> lk(contactsMtx_);
         if (contacts.find(uri) != contacts.end()) {
             // update contact and remove temporary item
-            contacts[uri].registeredName = registeredName;
+            contacts[uri].registeredName = foundName;
             searchResult.clear();
         } else {
-            nonContactLookup_[uri] = registeredName;
-            if ((searchQuery != uri && searchQuery != registeredName) || searchQuery.isEmpty()) {
+            nonContactLookup_[uri] = foundName;
+            if ((searchQuery != uri && searchQuery != requestedName) || searchQuery.isEmpty()) {
                 // we are notified that a previous lookup ended
                 return;
             }
             // Update the temporary item
             lrc::api::profile::Info profileInfo = {uri, "", "", profile::Type::TEMPORARY};
-            searchResult[uri] = {profileInfo, registeredName, false, false};
+            searchResult[uri] = {profileInfo, foundName, false, false};
         }
     } else {
         {
@@ -961,7 +980,7 @@ ContactModelPimpl::slotRegisteredNameFound(const QString& accountId,
                 return;
             }
         }
-        if ((searchQuery != uri && searchQuery != registeredName) || searchQuery.isEmpty()) {
+        if ((searchQuery != uri && searchQuery != requestedName) || searchQuery.isEmpty()) {
             // we are notified that a previous lookup ended
             return;
         }
@@ -973,7 +992,7 @@ ContactModelPimpl::slotRegisteredNameFound(const QString& accountId,
             updateTemporaryMessage(tr("Username not found"));
             break;
         case 3 /* ERROR */:
-            updateTemporaryMessage(tr("Couldn't lookup…"));
+            updateTemporaryMessage(tr("Unable to lookup…"));
             break;
         }
         return;
@@ -1051,7 +1070,7 @@ ContactModelPimpl::slotNewAccountMessage(const QString& accountId,
             if (potentialContact.isEmpty()) {
                 addToContacts(peerId, profile::Type::SIP, "", false);
             } else {
-                // equivalent uri exist, use that uri
+                // equivalent URI exist, use that URI
                 peerId2 = potentialContact;
             }
         } else {
@@ -1066,8 +1085,8 @@ ContactModelPimpl::slotNewAccountMessage(const QString& accountId,
 QString
 ContactModelPimpl::sipUriReceivedFilter(const QString& uri)
 {
-    // this function serves when the uri is not found in the contact list
-    // return "" means need to add new contact, else means equivalent uri exist
+    // this function serves when the URI is not found in the contact list
+    // return "" means need to add new contact, else means equivalent URI exist
     std::string uriCopy = uri.toStdString();
 
     auto pos = uriCopy.find("@");
@@ -1114,7 +1133,7 @@ ContactModelPimpl::sipUriReceivedFilter(const QString& uri)
         // no need to check country dial-in codes
         return "";
     }
-    // "@" is not found -> not possible since all response uri has one
+    // "@" is not found → impossible since all response URI has one
     return "";
 }
 
@@ -1170,16 +1189,21 @@ ContactModelPimpl::slotProfileReceived(const QString& accountId,
     if (accountId != linked.owner.id)
         return;
 
-    // Make sure this is for a contact and not the linked account,
-    // then just remove the URI from the cache list and notify.
-    std::lock_guard<std::mutex> lk(contactsMtx_);
-    if (contacts.find(peer) != contacts.end()) {
-        // Remove the URI from the cache list and notify.
-        cachedProfiles.remove(peer);
-        // This signal should be listened to in order to update contact display names
-        // and avatars in the client.
-        Q_EMIT linked.profileUpdated(peer);
+    if (linked.owner.profileInfo.uri == peer || peer == "") {
+        // as SIP account doesn't have a URI, we emit a signal with the accountId in the peer parameter
+        const auto newProfileInfo = storage::getProfileData(accountId, "");
+        linked.owner.accountModel->setAlias(accountId, newProfileInfo["alias"], false);
+        linked.owner.accountModel->setAvatar(accountId, newProfileInfo["avatar"], false);
+
+        Q_EMIT linked.owner.accountModel->profileUpdated(accountId);
+        return;
     }
+
+    // Remove the URI from the cache list and notify.
+    cachedProfiles.remove(peer);
+    // This signal should be listened to in order to update contact display names
+    // and avatars in the client.
+    Q_EMIT linked.profileUpdated(peer);
 }
 
 void
@@ -1212,7 +1236,7 @@ ContactModelPimpl::slotUserSearchEnded(const QString& accountId,
         updateTemporaryMessage("");
         break;
     case 3: /* ERROR */
-        updateTemporaryMessage("could not find contact matching search");
+        updateTemporaryMessage("Unable to find contact matching search");
         break;
     default:
         break;
@@ -1222,30 +1246,45 @@ ContactModelPimpl::slotUserSearchEnded(const QString& accountId,
 
 template<typename Func>
 QString
-ContactModelPimpl::getCachedProfileProperty(const QString& contactUri, Func extractor)
+ContactModelPimpl::getCachedProfileProperty(const QString& peerUri, Func extractor)
 {
     std::lock_guard<std::mutex> lk(contactsMtx_);
     // For search results it's loaded and not in storage yet.
-    if (searchResult.contains(contactUri)) {
-        auto contact = searchResult.value(contactUri);
+    if (searchResult.contains(peerUri)) {
+        auto contact = searchResult.value(peerUri);
         return extractor(contact.profileInfo);
     }
 
     // Try to find the contact.
-    auto it = contacts.find(contactUri);
-    if (it == contacts.end()) {
-        return {};
-    }
+    auto it = contacts.find(peerUri);
+    auto isContact = it != contacts.end();
+    auto getPInfo = [&]() -> profile::Info& {
+        if (!isContact) {
+            auto itNonContact = cachedProfilesInfo.find(peerUri);
+            if (itNonContact != cachedProfilesInfo.end()) {
+                return *itNonContact;
+            } else {
+                profile::Info pInfo;
+                pInfo.uri = peerUri;
+                pInfo.type = profile::Type::TEMPORARY;
+                cachedProfilesInfo.insert(peerUri, pInfo);
+                return cachedProfilesInfo[peerUri];
+            }
+        } else {
+            return it->profileInfo;
+        }
+    };
+    profile::Info& pInfo = getPInfo();
 
     // If we have a profile that appears to be recently cached, return the extracted property.
-    if (cachedProfiles.contains(contactUri)) {
-        return extractor(it->profileInfo);
+    if (cachedProfiles.contains(peerUri)) {
+        return extractor(pInfo);
     }
 
     // Otherwise, update the profile info and return the extracted property.
-    updateCachedProfile(it->profileInfo);
+    updateCachedProfile(pInfo);
 
-    return extractor(it->profileInfo);
+    return extractor(pInfo);
 }
 
 } // namespace lrc
