@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2020-2024 Savoir-faire Linux Inc.
+ *  Copyright (C) 2020-2025 Savoir-faire Linux Inc.
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -201,16 +201,14 @@ MessageListModel::update(const QString& id, const interaction::Info& interaction
             return true;
         }
     }
-    // DataTransfer interactions should not be updated.
-    if (current.type == interaction::Type::DATA_TRANSFER) {
-        return true;
-    }
-    // Just update bodies notify the view otherwise.
     current.body = interaction.body;
+    current.commit = interaction.commit;
     current.previousBodies = interaction.previousBodies;
     current.parsedBody = interaction.parsedBody;
     auto modelIndex = QAbstractListModel::index(indexOfMessage(id), 0);
-    Q_EMIT dataChanged(modelIndex, modelIndex, {Role::Body, Role::PreviousBodies, Role::ParsedBody});
+    Q_EMIT dataChanged(modelIndex,
+                       modelIndex,
+                       {Role::TID, Role::Body, Role::PreviousBodies, Role::ParsedBody});
     return true;
 }
 
@@ -225,7 +223,7 @@ MessageListModel::updateStatus(const QString& id,
         return false;
     }
     VectorInt roles;
-    if (it->second.status == newStatus) {
+    if (it->second.status >= newStatus) {
         return false;
     }
     it->second.status = newStatus;
@@ -249,6 +247,32 @@ MessageListModel::updateStatus(const QString& id,
     return true;
 }
 
+bool
+MessageListModel::updateTransferStatus(const QString& id,
+                                       interaction::TransferStatus newStatus,
+                                       const QString& newBody)
+{
+    VectorInt roles;
+    with(id, [&](const QString&, interaction::Info& interaction) {
+        if (interaction.transferStatus == newStatus) {
+            return;
+        }
+        interaction.transferStatus = newStatus;
+        roles.push_back(Role::TransferStatus);
+        if (!newBody.isEmpty()) {
+            interaction.body = newBody;
+            roles.push_back(Role::Body);
+        }
+    });
+    if (roles.empty()) {
+        return false;
+    }
+    auto idx = indexOfMessage(id);
+    auto modelIndex = QAbstractListModel::index(idx, 0);
+    Q_EMIT dataChanged(modelIndex, modelIndex, roles);
+    return true;
+}
+
 QPair<bool, bool>
 MessageListModel::addOrUpdate(const QString& id, const interaction::Info& interaction)
 {
@@ -503,7 +527,7 @@ MessageListModel::dataForItem(const item_t& item, int, int role) const
                 auto bestName = item.second.authorUri == account_->profileInfo.uri
                                     ? account_->accountModel->bestNameForAccount(account_->id)
                                     : account_->contactModel->bestNameForContact(
-                                        item.second.authorUri);
+                                          item.second.authorUri);
                 return QVariant(
                     interaction::getContactInteractionString(bestName,
                                                              interaction::to_action(
@@ -529,6 +553,8 @@ MessageListModel::dataForItem(const item_t& item, int, int role) const
         return QVariant(static_cast<int>(item.second.type));
     case Role::Status:
         return QVariant(static_cast<int>(item.second.status));
+    case Role::TransferStatus:
+        return QVariant(static_cast<int>(item.second.transferStatus));
     case Role::IsRead:
         return QVariant(item.second.isRead);
     case Role::LinkPreviewInfo:
@@ -569,6 +595,8 @@ MessageListModel::dataForItem(const item_t& item, int, int role) const
         return QVariant(item.second.commit["totalSize"].toInt());
     case Role::TransferName:
         return QVariant(item.second.commit["displayName"]);
+    case Role::TID:
+        return QVariant(item.second.commit["tid"]);
     case Role::FileExtension:
         return QVariant(QFileInfo(item.second.body).suffix());
     case Role::Readers:
