@@ -1,7 +1,5 @@
 /******************************************************************************
- *   Copyright (C) 2014-2024 Savoir-faire Linux Inc.                          *
- *   Author : Philippe Groarke <philippe.groarke@savoirfairelinux.com>        *
- *   Author : Alexandre Lision <alexandre.lision@savoirfairelinux.com>        *
+ *   Copyright (C) 2014-2025 Savoir-faire Linux Inc.                          *
  *                                                                            *
  *   This library is free software; you can redistribute it and/or            *
  *   modify it under the terms of the GNU Lesser General Public               *
@@ -152,11 +150,23 @@ public:
                                                         QString(displayName.c_str()),
                                                         QString(userPhoto.c_str()));
                 }),
-            exportable_callback<ConfigurationSignal::ExportOnRingEnded>(
-                [this](const std::string& accountId, int status, const std::string& pin) {
-                    Q_EMIT this->exportOnRingEnded(QString(accountId.c_str()),
-                                                   status,
-                                                   QString(pin.c_str()));
+            exportable_callback<ConfigurationSignal::AddDeviceStateChanged>(
+                [this](const std::string& accountId,
+                       uint32_t operationId,
+                       int state,
+                       const std::map<std::string, std::string>& details) {
+                    Q_EMIT this->addDeviceStateChanged(QString(accountId.c_str()),
+                                                       operationId,
+                                                       state,
+                                                       convertMap(details));
+                }),
+            exportable_callback<ConfigurationSignal::DeviceAuthStateChanged>(
+                [this](const std::string& accountId,
+                       int state,
+                       const std::map<std::string, std::string>& details) {
+                    Q_EMIT this->deviceAuthStateChanged(QString(accountId.c_str()),
+                                                        state,
+                                                        convertMap(details));
                 }),
             exportable_callback<ConfigurationSignal::NameRegistrationEnded>(
                 [this](const std::string& accountId, int status, const std::string& name) {
@@ -166,10 +176,12 @@ public:
                 }),
             exportable_callback<ConfigurationSignal::RegisteredNameFound>(
                 [this](const std::string& accountId,
+                       const std::string& requestedName,
                        int status,
                        const std::string& address,
                        const std::string& name) {
                     Q_EMIT this->registeredNameFound(QString(accountId.c_str()),
+                                                     QString(requestedName.c_str()),
                                                      status,
                                                      QString(address.c_str()),
                                                      QString(name.c_str()));
@@ -431,9 +443,28 @@ public Q_SLOTS: // METHODS
                               path.toStdString());
     }
 
-    bool exportOnRing(const QString& accountId, const QString& password)
+    bool provideAccountAuthentication(const QString& accountId,
+                                      const QString& credentialsFromUser,
+                                      const QString scheme = "password")
     {
-        return libjami::exportOnRing(accountId.toStdString(), password.toStdString());
+        return libjami::provideAccountAuthentication(accountId.toStdString(),
+                                                     credentialsFromUser.toStdString(),
+                                                     scheme.toStdString());
+    }
+
+    int32_t addDevice(const QString& accountId, const QString& token)
+    {
+        return libjami::addDevice(accountId.toStdString(), token.toStdString());
+    }
+
+    bool confirmAddDevice(const QString& accountId, uint32_t operationId)
+    {
+        return libjami::confirmAddDevice(accountId.toStdString(), operationId);
+    }
+
+    bool cancelAddDevice(const QString& accountId, uint32_t operationId)
+    {
+        return libjami::cancelAddDevice(accountId.toStdString(), operationId);
     }
 
     bool exportToFile(const QString& accountId,
@@ -469,7 +500,10 @@ public Q_SLOTS: // METHODS
                                       address.toStdString());
     }
 
-    bool registerName(const QString& accountId, const QString& name, const QString& scheme, const QString& password)
+    bool registerName(const QString& accountId,
+                      const QString& name,
+                      const QString& scheme,
+                      const QString& password)
     {
         return libjami::registerName(accountId.toStdString(),
                                      name.toStdString(),
@@ -483,6 +517,21 @@ public Q_SLOTS: // METHODS
         return temp;
     }
 
+    void updateProfile(const QString& accountId,
+                       const QString& displayName,
+                       const QString& avatarPath,
+                       const QString& fileType,
+                       int flag)
+    {
+        // file type is set to PNG by default
+        // it can be changed to JPEG to optimize compression
+        libjami::updateProfile(accountId.toStdString(),
+                               displayName.toStdString(),
+                               avatarPath.toStdString(),
+                               fileType.toStdString(),
+                               flag);
+    }
+
     QStringList getAccountList()
     {
         return convertStringList(libjami::getAccountList());
@@ -835,7 +884,10 @@ public Q_SLOTS: // METHODS
         libjami::removeContact(accountId.toStdString(), uri.toStdString(), ban);
     }
 
-    void revokeDevice(const QString& accountId, const QString& deviceId, const QString& scheme, const QString& password)
+    void revokeDevice(const QString& accountId,
+                      const QString& deviceId,
+                      const QString& scheme,
+                      const QString& password)
     {
         libjami::revokeDevice(accountId.toStdString(),
                               deviceId.toStdString(),
@@ -1175,7 +1227,11 @@ Q_SIGNALS: // SIGNALS
                                  const QString& certId,
                                  const QString& status);
     void knownDevicesChanged(const QString& accountId, const MapStringString& devices);
-    void exportOnRingEnded(const QString& accountId, int status, const QString& pin);
+    void addDeviceStateChanged(const QString& accountId,
+                               uint32_t operationId,
+                               int state,
+                               const MapStringString& details);
+    void deviceAuthStateChanged(const QString& accountId, int state, const MapStringString& details);
     void incomingAccountMessage(const QString& accountId,
                                 const QString& from,
                                 const QString msgId,
@@ -1191,9 +1247,10 @@ Q_SIGNALS: // SIGNALS
     void needsHost(const QString& accountId, const QString& conversationId);
     void nameRegistrationEnded(const QString& accountId, int status, const QString& name);
     void registeredNameFound(const QString& accountId,
+                             const QString& requestedName,
                              int status,
                              const QString& address,
-                             const QString& name);
+                             const QString& registeredName);
     void migrationEnded(const QString& accountId, const QString& result);
     void contactAdded(const QString& accountId, const QString& uri, bool banned);
     void contactRemoved(const QString& accountId, const QString& uri, bool banned);
